package com.seostella.swftests.service;

import com.seostella.swftests.domain.Test;
import com.seostella.swftests.domain.TestList;
import com.seostella.swftests.flow.exception.test.LastTestException;
import com.seostella.swftests.flow.exception.test.MaxWrongAnswersException;
import com.seostella.swftests.flow.exception.test.WrongAnswerException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author seostella.com
 */
@SuppressWarnings("serial")
public class QuestionService implements Serializable{
    private static final int MAX_WRONG_ANSWER = 3;
    private List<Test> tests;
    private int testIndex = 0;

    public QuestionService() {
        tests = new ArrayList<Test>();
        tests.add(new Test(
                "Сколько оборотов вокруг Солнца делает Земля за один год?", 
                "1", "4", "365", 
                1 
                ));
        tests.add(new Test(
                "Сколько лет длилась Столетняя война?", 
                "86", "100", "116", 
                1 
                ));
        tests.add(new Test(
                "Сколько игроков в футбольной комманде?", 
                "9", "10", "11", 
                3
                ));
        tests.add(new Test(
                "Какой океан омывает Индию", 
                "Индийский", "Тихий", "Атлантический", 
                1
                ));
        tests.add(new Test(
                "Столица Англии?", 
                "Париж", "Барселона", "Лондон", 
                3
                ));
    }
    
    public Test getNextTest(){
        return tests.get(testIndex++);
    }
    
    public boolean isLastQuestion(){
        if( testIndex >= tests.size() ){
            return true;
        }
        return false;
    }
    
    public void addAnswer( TestList testList, Test test )
            throws LastTestException, WrongAnswerException, MaxWrongAnswersException{
        testList.addAnswer(test);
        
        if ( !test.isCorrectAnswer() ) {
            if (testList.getWrongAnswerCount() >= MAX_WRONG_ANSWER) {
                throw new MaxWrongAnswersException();
            }
            checkTestIsLast();
            throw new WrongAnswerException();
        }
        checkTestIsLast();
    }
    
    private void checkTestIsLast() throws LastTestException{
        if ( isLastQuestion() ) {
            testIndex = 0;
            throw new LastTestException();
        }        
    }
}
